.. _capi-residue:

Function manipulating ``CHFL_RESIDUE``
--------------------------------------

.. doxygentypedef:: CHFL_RESIDUE

.. doxygenfunction:: chfl_residue

.. doxygenfunction:: chfl_residue_with_id

.. doxygenfunction:: chfl_residue_for_atom

.. doxygenfunction:: chfl_residue_from_topology

.. doxygenfunction:: chfl_residue_copy

.. doxygenfunction:: chfl_residue_name

.. doxygenfunction:: chfl_residue_id

.. doxygenfunction:: chfl_residue_add_atom

.. doxygenfunction:: chfl_residue_atoms_count

.. doxygenfunction:: chfl_residue_atoms

.. doxygenfunction:: chfl_residue_contains

.. doxygenfunction:: chfl_residue_free
